/* Webcamoid, webcam capture application.
 * Copyright (C) 2016  Gonzalo Exequiel Pedone
 *
 * Webcamoid is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Webcamoid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Webcamoid. If not, see <http://www.gnu.org/licenses/>.
 *
 * Web-Site: http://webcamoid.github.io/
 */

#include <QQmlEngine>

#include "charify.h"
#include "charifyelement.h"

QObject *Charify::create(const QString &key, const QString &specification)
{
    Q_UNUSED(key)
    Q_UNUSED(specification)
    qRegisterMetaType<CharifyElement::ColorMode>("CharifyElementColorMode");
    qRegisterMetaTypeStreamOperators<CharifyElement::ColorMode>("CharifyElementColorMode");
    qmlRegisterType<CharifyElement>("CharifyElement", 1, 0, "CharifyElement");

    return new CharifyElement();
}

QStringList Charify::keys() const
{
    return {};
}

#include "moc_charify.cpp"
